@@ -9,7 +9,7 @@ import { createTestModel } from './utils';
 import { WidgetCodeModel } from '..';
 
 describe('Example', () => {
-  describe('WidgetCodeModel', () => {
+  describe('ExampleModel', () => {
     it('should be createable', () => {
       const model = createTestModel(WidgetCodeModel);
       expect(model).toBeInstanceOf(WidgetCodeModel);
